@@ -26,6 +26,7 @@ static inline void r_str_rmch(char *s, char ch) {
 	}
 }
 
+#define R_STR_ISEMPTY(x) (!(x) || !*(x))
 #define R_STR_DUP(x) ((x) ? strdup ((x)) : NULL)
 #define r_str_array(x,y) ((y>=0 && y<(sizeof(x)/sizeof(*x)))?x[y]:"")
 R_API const char *r_str_pad(const char ch, int len);
@@ -62,12 +63,14 @@ R_API int r_str_replace_char_once(char *s, int a, int b);
 R_API const char *r_str_rwx_i(int rwx);
 R_API void r_str_writef(int fd, const char *fmt, ...);
 R_API char *r_str_arg_escape(const char *arg);
+R_API int r_str_arg_unescape(char *arg);
 R_API char **r_str_argv(const char *str, int *_argc);
 R_API void r_str_argv_free(char **argv);
 R_API char *r_str_new(const char *str);
 R_API int r_snprintf (char *string, int len, const char *fmt, ...);
 R_API bool r_str_is_ascii(const char *str);
 R_API int r_str_is_printable(const char *str);
+R_API int r_str_is_printable_limited(const char *str, int size);
 R_API bool r_str_is_printable_incl_newlines(const char *str);
 R_API char *r_str_appendlen(char *ptr, const char *string, int slen);
 R_API char *r_str_newf(const char *fmt, ...);
@@ -142,6 +145,7 @@ R_API char *r_str_uri_encode(const char *buf);
 R_API char *r_str_utf16_decode(const ut8 *s, int len);
 R_API int r_str_utf16_to_utf8(ut8 *dst, int len_dst, const ut8 *src, int len_src, int little_endian);
 R_API char *r_str_utf16_encode(const char *s, int len);
+R_API char *r_str_escape_utf8_to_json(const char *s, int len);
 R_API char *r_str_home(const char *str);
 R_API char *r_str_r2_prefix(const char *str);
 R_API int r_str_nlen(const char *s, int n);
